import { query } from '../database/db';
import { fetchGroups, configureWebhook } from './utils/api';
import { startCleanupJob } from '../jobs/cleanupJob';

export const linkedGroups: Set<string> = new Set();

export async function startBot() {
  const communityId = process.env.COMMUNITY_ID;
  const webhookUrl = process.env.WEBHOOK_URL;

  if (!communityId || !webhookUrl) {
    throw new Error('Required environment variables are not defined.');
  }

  // Load linked groups from the database
  const groups = query('SELECT id FROM groups WHERE linked_parent = ?', [communityId]);
  for (const group of groups) {
    linkedGroups.add(group.id);
  }

  await fetchGroups(communityId);
  await configureWebhook(webhookUrl);
  
  // Start the cleanup job
  startCleanupJob();
}
