export function normalizeUserIdentifier(input: string): string {
  console.log('Normalizing user identifier:', input);
  
  // Handle JID format (12345678@s.whatsapp.net)
  if (input.includes('@s.whatsapp.net')) {
    const [phone, domain] = input.split('@');
    const cleanPhone = phone.replace(/\D/g, '');
    return `${cleanPhone}@${domain}`;
  }

  // Remove @ prefix if present
  const cleanInput = input.startsWith('@') ? input.slice(1) : input;
  
  // Remove any non-numeric characters
  const phoneNumber = cleanInput.replace(/\D/g, '');
  
  // Validate phone number length
  if (phoneNumber.length < 8 || phoneNumber.length > 15) {
    throw new Error('Número de teléfono inválido');
  }
  
  const jid = `${phoneNumber}@s.whatsapp.net`;
  console.log('Normalized JID:', jid);
  return jid;
}

export function extractUserFromJid(jid: string): string {
  // Extract phone number from JID (format: 12345678@s.whatsapp.net)
  const phoneNumber = jid.split('@')[0];
  return normalizeUserIdentifier(phoneNumber);
}

export function formatUserMention(phoneNumber: string): string {
  return `@${phoneNumber.replace('@', '')}`;
}
